==> lynx-cli-1.0.1.tgz: package/lib/debug-server.js <==
const fs = require('fs')
const path = require('path')
const express = require('express')
const bodyParser = require('body-parser')
const vueServerRenderer = require(process.cwd() + '/libs/vue-server-renderer')

module.exports = function () {
  const app = express()
  const server = require('http').createServer(app)
  app.use(bodyParser.json({ limit: '1mb' }));  
  app.use(bodyParser.urlencoded({
    extended: true
  }));

  // Server-Side Bundle File
  const serverBundleFilePath = path.join(process.cwd(), '/pack/out/bundle.server.js')
  const serverBundleFileCode = fs.readFileSync(serverBundleFilePath, 'utf8');
  const bundleRenderer = vueServerRenderer.createBundleRenderer(serverBundleFileCode);

  // Client-Side Bundle File
  const clientBundleFilePath = path.join(process.cwd(), 'out/bundle.client.js');
  const clientBundleFileUrl = '/bundle.client.js';

  // Server-Side Rendering
  app.get('/', function (req, res) {
    bundleRenderer.renderToString((err, html) => {
      if (err) {
        res.status(500).send(`
        <h1>Error: ${err.message}</h1>
        <pre>${err.stack}</pre>
      `);
      } else {
        res.send(`
        <!DOCTYPE html>
        <html>
          <head>
            <meta charset="utf-8">
            <title>Vue 2.0 SSR</title>
          </head>
          <body>
            ${html}
            <script src="${clientBundleFileUrl}"></script>
          </body>
        </html>`);
      }
    });
  });

  app.get('/data', function (req, res) {
    function randNum() {
      return Math.round(Math.random() * 100);
    }
    res.send({
      name: `Hans-${randNum()}`,
      age: randNum(),
    });
  });

  // Client-Side Bundle File
  app.get(clientBundleFileUrl, function (req, res) {
    const clientBundleFileCode = fs.readFileSync(clientBundleFilePath, 'utf8');
    res.send(clientBundleFileCode);
  });

  app.post('/log', function (req, res) {
    console.log(req.body.log)
    res.send('')
  })

  const net = require('net')

  function push(socket, command) {
    socket.write(command)
    socket.end()
  }

  function sendCommand(command) {
    var HOST = '127.0.0.1'
    var POST = 8000
    var socket = new net.Socket()
    socket.connect(POST, HOST, function () {
      socket.write(command)
      socket.end()
    })
  }

  // Start server
  const PORT = process.env.PORT || 3000;
  app.listen(PORT, function () {
    sendCommand('reload')
  });
}

==> lynx-cli-1.0.3.tgz: package/lib/debug-server.js <==
const fs = require('fs')
const path = require('path')
const express = require('express')
const bodyParser = require('body-parser')
const reload = require('./reload')
const vueServerRenderer = require(process.cwd() + '/libs/vue-server-renderer')

module.exports = function () {
  const app = express()
  const server = require('http').createServer(app)
  app.use(bodyParser.json({ limit: '1mb' }));  
  app.use(bodyParser.urlencoded({
    extended: true
  }));

  // Server-Side Bundle File
  const serverBundleFilePath = path.join(process.cwd(), '/pack/out/bundle.server.js')
 
  // Client-Side Bundle File
  const clientBundleFilePath = path.join(process.cwd(), 'out/bundle.client.js');
  const clientBundleFileUrl = 'bundle.client.js';

  // Server-Side Rendering
  app.get('/', function (req, res) {
    const serverBundleFileCode = fs.readFileSync(serverBundleFilePath, 'utf8');
    const bundleRenderer = vueServerRenderer.createBundleRenderer(serverBundleFileCode);
    bundleRenderer.renderToString((err, html) => {
      if (err) {
        res.status(500).send(`
        <h1>Error: ${err.message}</h1>
        <pre>${err.stack}</pre>
      `);
      } else {
        res.send(`<body>
            ${html}
            <script src="${clientBundleFileUrl}"></script>
          </body>`);
      }
    });
  });

  app.get('/data', function (req, res) {
    function randNum() {
      return Math.round(Math.random() * 100);
    }
    res.send({
      name: `Hans-${randNum()}`,
      age: randNum(),
    });
  });

  // Client-Side Bundle File
  app.get('/'+clientBundleFileUrl, function (req, res) {
    const clientBundleFileCode = fs.readFileSync(clientBundleFilePath, 'utf8');
    res.send(clientBundleFileCode);
  });

  app.get('*.png', function(req, res) {
    var imgPath = path.join(process.cwd(), 'out');
    const img = fs.readFileSync(imgPath + req.url);
    res.send(img);
  })

  app.post('/log', function (req, res) {
    console.log(req.body.log)
    res.send('')
  })

  // Start server
  const PORT = process.env.PORT || 3000;
  app.listen(PORT, function () {
    reload()
  });
}
